@@ -4,6 +4,8 @@ from .shipmatrix import ShipMatrixAPI
 from .org import OrgAPI
 from .citizen import fetch_citizen
 from .status import Status
+from .roadmap import Roadmap
+from .hangar import Hangar
 
 
 class RSISite:
@@ -14,6 +16,8 @@ class RSISite:
 
         self.store = PledgeStore(session=self.session)
         self.ships = ShipMatrixAPI(session=self.session)
+        self.roadmap = Roadmap(session=self.session)
+        self._hangar = None
         self.status = Status()
 
     @property
@@ -28,3 +32,9 @@ class RSISite:
 
     def org(self, symbol):
         return OrgAPI(symbol=symbol, session=self.session)
+
+    @property
+    def hangar(self):
+        if self._hangar is None:
+            self._hangar = Hangar(self.session)
+        return self._hangar
