@@ -1,4 +1,5 @@
 import os
+import sys
 import codecs
 import pickle
 import requests
@@ -62,6 +63,7 @@ class RSISession(requests.Session):
         self.persist_session = persist_session
         self.session_name = 'RSI-Token'
         self.session_id = ''
+        self.username = username
 
         if clear_session:
             self.clear_session()
@@ -79,9 +81,10 @@ class RSISession(requests.Session):
             self.cookies.update(pickle.loads(codecs.decode(cookies.encode(), "base64")))
         self._update_session(self._config.get('RSI', 'session_name', fallback=''),
                              self._config.get('RSI', 'session_id', fallback=''),
+                             self._config.get('RSI', 'username', fallback=''),
                              save=False)
 
-    def _update_session(self, name, id, save=True):
+    def _update_session(self, name, id, username='', save=True):
         if not id:
             # if id has been cleared, clear the session
             if name in self.headers:
@@ -93,6 +96,8 @@ class RSISession(requests.Session):
             self.session_id = id
             self.headers.update({'X-{}'.format(name): id})
 
+        self.username = username
+        self._config.set('RSI', 'username', username)
         self._config.set('RSI', 'session_name', name)
         self._config.set('RSI', 'session_id', id)
         self._config.set('RSI', 'cookies', codecs.encode(pickle.dumps(self.cookies), "base64").decode())
@@ -104,7 +109,7 @@ class RSISession(requests.Session):
         # called on the response hook and will update the session id from the cookie
         if self.session_name in response.cookies:
             if response.cookies[self.session_name] != self.session_id:
-                self._update_session(self.session_name, self.session_id)
+                self._update_session(self.session_name, self.session_id, self.username)
 
     def query_api(self, api, json=None):
         resp = self.post(api, json=json)
@@ -140,17 +145,24 @@ class RSISession(requests.Session):
         if not force and self.is_authenticated:
             return
 
-        self._update_session(self.session_name, '')
+        self.username = username
+        self._update_session(self.session_name, '', username)
 
         success, info = self.query_api(self._login_api, json={
             'username': username,
             'password': password,
             'remember': 'off'})
 
+        if not success and info.get('code', '') == 'ErrCaptchaRequiredLauncher':
+            print(info.get('msg'))
+            sys.exit(1)
+
         if not success and info.get('code', '') == 'ErrMultiStepRequired':
             # Two factor auth required, ask user for
             if not self._allow_two_factor:
                 raise Exception('Account requires Two Factor authentication which has been disabled')
+            if 'msg' in info:
+                print(info['msg'])
             self._update_session(info['data']['session_name'], info['data']['session_id'])
             code = self.two_factor_prompt()
             success, info = self.query_api(self._login_two_factor_api, json={
